@@ -2,7 +2,7 @@
 import aiohttp
 import urllib
 
-# import asyncio
+import asyncio
 import jsonrpc_base
 import jsonrpc_async
 import jsonrpc_websocket
@@ -133,7 +133,7 @@ class KodiWSConnection(KodiConnection):
             return
         try:
             await self._ws_server.ws_connect()
-        except jsonrpc_base.jsonrpc.TransportError as error:
+        except (jsonrpc_base.jsonrpc.TransportError, asyncio.exceptions.CancelledError) as error:
             raise CannotConnectError from error
 
     async def close(self):
@@ -358,6 +358,12 @@ class Kodi:
             _build_query(properties=properties)
         )
 
+    async def get_movie_details(self, movie_id, properties=None):
+        """Get movie details."""
+        return await self._server.VideoLibrary.GetMovieDetails(
+            _build_query(movieid=movie_id, properties=properties)
+        )
+
     async def get_seasons(self, tv_show_id, properties=None):
         """Get seasons list."""
         return await self._server.VideoLibrary.GetSeasons(
